@@ -11,6 +11,7 @@ class AutoConvHandler:
 		self.back_button = back_button
 		self.prev_state = None
 		self.curr_state = conversation.start
+		self.update, self.context = None, None
 
 	def _build_keyboard(self,state):
 		'''Build Keyboard for callback state'''
@@ -53,20 +54,32 @@ class AutoConvHandler:
 		query.edit_message_text(f"{new_state}",reply_markup=keyboard,parse_mode=new_state.mode)
 		return self.NEXT
 
-	def manage_conversation(self,update,context):
+	def restart(self):
+		if self.update:
+			telegram_id = self.update.effective_chat.id
+			if (c := self.context.user_data.get(telegram_id)):
+				if (m := c.get('bot-msg')): m.delete()
+				self.context.user_data.pop(telegram_id)
+			self.prev_state = None
+			self.curr_state = self.conversation.start
+		return self
+
+	def manage_conversation(self,update,context,delete_first=True):
 		'''Master function for converastion'''
 		self.update = update
 		self.context = context
 		telegram_id = self.update.effective_chat.id
 		# start
 		if not self.context.user_data.get(telegram_id):
+			if delete_first: update.message.delete()
 			state = self.conversation.start
+			self.context.user_data.update({telegram_id:{'state':state,'error':False,'data':{}}})
 			if state.build: state.add_keyboard(state.build(self.update,self.context),max_row=state.max_row)
 			keyboard = self._build_keyboard(state)
 			ret = state.action(self.update,self.context) if state.action else None
 			reply_msg = state.msg if ret == None else state.msg.replace('@@@',ret)
 			msg = self.update.message.reply_text(f'{reply_msg}',reply_markup=keyboard,parse_mode=state.mode)
-			self.context.user_data.update({telegram_id:{'state':state,'error':False,'bot-msg':msg,'data':{}}})
+			self.context.user_data.get(telegram_id).update({'bot-msg':msg})
 			return self.NEXT
 		# get data
 		state = self.context.user_data.get(telegram_id).get('state')
@@ -82,10 +95,13 @@ class AutoConvHandler:
 		# next stage
 		typed_data = state.data_type(data) if data != 'BACK' else 'BACK'
 		state = self._change_state(telegram_id,typed_data)
+		ret = state.action(self.update,self.context) if state.action else None
+		if state.routes:
+			ro,de,ba = state.routes(self.update,self.context)
+			self.conversation.add_routes(state,ro,de,ba)
+		msg = state.msg if ret == None else state.msg.replace('@@@',ret)
 		if state.build: state.add_keyboard(state.build(self.update,self.context),max_row=state.max_row)
 		keyboard = self._build_keyboard(state)
-		ret = state.action(self.update,self.context) if state.action else None
-		msg = state.msg if ret == None else state.msg.replace('@@@',ret)
 		to_reply(f'{msg}',reply_markup=keyboard,parse_mode=state.mode,disable_web_page_preview=not state.webpage_preview)
 		if state == self.conversation.end: context.user_data.update({telegram_id:None}); return ConversationHandler.END
 		return self.NEXT
\ No newline at end of file
